@@ -4,12 +4,12 @@ setGeneric( "containing_type", function(object){
 } )
 
 setMethod( "containing_type", "Descriptor", function(object){
-	.Call( "containing_type__Descriptor", object@pointer, PACKAGE = "RProtoBuf" )
+	.Call( "Descriptor__containing_type", object@pointer, PACKAGE = "RProtoBuf" )
 } )
 setMethod( "containing_type", "EnumDescriptor", function(object){
-	.Call( "containing_type__EnumDescriptor", object@pointer, PACKAGE = "RProtoBuf" )
+	.Call( "EnumDescriptor__containing_type", object@pointer, PACKAGE = "RProtoBuf" )
 } )
 setMethod( "containing_type", "FieldDescriptor", function(object){
-	.Call( "containing_type__FieldDescriptor", object@pointer, PACKAGE = "RProtoBuf" )
+	.Call( "FieldDescriptor__containing_type", object@pointer, PACKAGE = "RProtoBuf" )
 } )
 
